pub fn annotate_all_cycles(graphs: &mut PluginGraphs)Expand description
Detect SCCs in the file graph and annotate nodes + the graph’s cycles
field in-place.
pub fn annotate_all_cycles(graphs: &mut PluginGraphs)Detect SCCs in the file graph and annotate nodes + the graph’s cycles
field in-place.