Module snapshot

Module snapshot 

Structs

GitInfo
PluginGraphs
Snapshot
StageTime

Functions

relativize_graphs
Rewrite all node path fields to be relative:
rewrite_ids
Rewrite all node id, parent and edge from/to fields from the raw cargo-based IDs to short human-readable IDs.
to_canonical_string
Compact counterpart of to_canonical_string_pretty (no indentation).
to_canonical_string_pretty
Serialize to canonical pretty JSON: every object key is emitted in alphabetical order and the graph nodes / edges arrays are sorted by a stable key (id for nodes; from, to, kind for edges). This makes the output byte-stable for unchanged input — re-running the analysis never reorders keys (e.g. from HashMap iteration order) or array entries.